%define gccinstalldir	%(LC_ALL=C %__cc --print-search-dirs | grep install | %__awk '{print $2}')
%define _fmoddir	%{gccinstalldir}/finclude

%define major		2
%define libname		%mklibname symspg %{major}
%define develname	%mklibname %{name} -d

%define libname_f08	%mklibname %{name}-f08_ %{major}
%define develname_f08	%mklibname %{name}-f08 -d

%bcond_without python

Name:		spglib
Version:	2.5.0
Release:	%mkrel 3
Summary:	C library for finding and handling crystal symmetries
License:	BSD
Group:		System/Libraries
Url:		https://spglib.readthedocs.io/
Source0:	https://github.com/spglib/spglib/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:		spglib-linking-python-module.patch
Patch1:		0001-Make-project-PEP639-compatible.patch
Patch2:		Relax_numpy_requirements.patch
BuildRequires:	ninja-build
BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	gcc-gfortran
BuildRequires:	pkgconfig(gtest)
%if %{with python}
BuildRequires:	pkgconfig(python3)
BuildRequires:	pyproject-rpm-macros
BuildRequires:	python3-numpy-devel
BuildRequires:	python3dist(numpy)
BuildRequires:	python3dist(pip)
BuildRequires:	python3dist(pytest)
BuildRequires:	python3dist(pyyaml)
BuildRequires:	python3dist(scikit-build-core)
BuildRequires:	python3dist(setuptools-scm)
%endif

%description
C library for finding and handling crystal symmetries.

#----------------------------------------------------

%package -n	%{libname}
Summary:	C library for finding and handling crystal symmetries
Group:		System/Libraries

%description -n	%{libname}
C library for finding and handling crystal symmetries.
This package contains library files for %{name}.

#----------------------------------------------------

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	libspg-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains libraries and header files for
developing applications that use %{name}.

#----------------------------------------------------

%package -n	%{libname_f08}
Summary:	Runtime files for spglib Fortran bindings
Group:		System/Libraries
Requires:	gcc-gfortran%{_isa}

%description -n	%{libname_f08}
This package contains runtime files to run applications that were built
using spglib's Fortran bindings.

#----------------------------------------------------

%package -n	%{develname_f08}
Summary:	Development files for spglib with Fortran bindings
Group:		Development/C
Requires:	%{libname_f08} = %{version}-%{release}
Requires:	%{develname} = %{version}-%{release}
Provides:	%{name}-fortran-devel = %{version}-%{release}

%description -n	%{develname_f08}
This package contains Fortran module and header files for developing
Fortran applications that use spglib.

#----------------------------------------------------
%if %{with python}

%package -n	python3-%{name}
Summary:	Python3 library of spglib
Group:		Development/Python

%description -n	python3-%{name}
This package contains the libraries to
develop applications with spglib Python3 bindings.
%endif

#----------------------------------------------------

%prep
%autosetup -p1

%generate_buildrequires
%pyproject_buildrequires

%build
%cmake \
    -DSPGLIB_SHARED_LIBS=ON \
    -DSPGLIB_WITH_Fortran=ON \
    -DSPGLIB_WITH_Python=OFF \
    -DSPGLIB_WITH_TESTS=ON \
    -DCMAKE_INSTALL_MODULEDIR=%{_fmoddir}
%cmake_build

%if %{with python}
%pyproject_wheel
%endif

%install
%cmake_install

%if %{with python}
%pyproject_install
%pyproject_save_files spglib

rm %{buildroot}%{python3_sitearch}/spglib/lib/libsymspg.so*
rm %{buildroot}%{python3_sitearch}/spglib/include/spglib.h

# Delete from pyproject_files as well
sed -i "/libsymspg.so/d" %{pyproject_files}
sed -i "/spglib.h/d" %{pyproject_files}
%endif

%check
#ctest
%if %{with python}
# Need to set LD_LIBRARY_PATH manually for this test
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %pytest -v
%endif

%files -n %{libname}
%doc README.md
%license COPYING
%{_libdir}/libsymspg.so.%{major}{,.*}

%files -n %{libname_f08}
%license COPYING
%{_libdir}/libspglib_f08.so.%{major}{,.*}

%files -n %{develname}
%doc ChangeLog.md README.md
%license COPYING
%{_includedir}/%{name}.h
%{_libdir}/libsymspg.so
%{_libdir}/cmake/Spglib/
%{_libdir}/pkgconfig/spglib.pc
%exclude %{_libdir}/cmake/Spglib/SpglibTargets_fortran*

%files -n %{develname_f08}
%doc ChangeLog.md README.md
%license COPYING
%{_includedir}/spglib_f08.F90
%{_libdir}/libspglib_f08.so
%{_libdir}/cmake/Spglib/SpglibTargets_fortran*
%{_fmoddir}/spglib_f08.mod
%{_libdir}/pkgconfig/spglib_f08.pc

%if %{with python}
%files -n python3-%{name} -f %{pyproject_files}
%endif


%changelog
* Tue Mar 04 2025 daviddavid <daviddavid> 2.5.0-3.mga10
+ Revision: 2160705
- backport upstream patch to fix build
+ wally <wally>
- rebuild for python3.13

* Fri Sep 27 2024 daviddavid <daviddavid> 2.5.0-2.mga10
+ Revision: 2101517
- rebuild against numpy 2

* Sat Jul 27 2024 daviddavid <daviddavid> 2.5.0-1.mga10
+ Revision: 2082640
- new version: 2.5.0

* Mon Apr 22 2024 daviddavid <daviddavid> 2.4.0-1.mga10
+ Revision: 2060500
- new version: 2.4.0

* Thu Feb 22 2024 daviddavid <daviddavid> 2.3.1-1.mga10
+ Revision: 2043035
- new version: 2.3.1

* Mon Dec 25 2023 daviddavid <daviddavid> 2.2.0-2.mga10
+ Revision: 2021188
- rebuild for py3.12

* Thu Dec 14 2023 daviddavid <daviddavid> 2.2.0-1.mga10
+ Revision: 2017965
- new version: 2.2.0

* Sat Nov 04 2023 daviddavid <daviddavid> 2.1.0-2.mga10
+ Revision: 2003912
- enable python3 bindings

* Fri Nov 03 2023 daviddavid <daviddavid> 2.1.0-1.mga10
+ Revision: 2003728
- new version: 2.1.0
- now libmajor is 2
- switch to cmake build system
- new fortran sub-pkgs
+ neoclust <neoclust>
- New version 	2.0.1

* Wed Mar 16 2022 umeabot <umeabot> 1.16.1-2.mga9
+ Revision: 1794619
- Mageia 9 Mass Rebuild

* Fri Feb 26 2021 daviddavid <daviddavid> 1.16.1-1.mga9
+ Revision: 1691685
- new version: 1.16.1

* Sun Aug 02 2020 daviddavid <daviddavid> 1.16.0-1.mga8
+ Revision: 1610489
- new version: 1.16.0

* Fri May 01 2020 daviddavid <daviddavid> 1.15.1-1.mga8
+ Revision: 1577364
- new version: 1.15.1

* Tue Apr 21 2020 daviddavid <daviddavid> 1.15.0-1.mga8
+ Revision: 1570225
- new version: 1.15.0

* Sat Feb 15 2020 umeabot <umeabot> 1.14.1-2.mga8
+ Revision: 1528346
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Aug 19 2019 daviddavid <daviddavid> 1.14.1-1.mga8
+ Revision: 1429928
- new version: 1.14.1

* Fri Jul 19 2019 daviddavid <daviddavid> 1.13.0-1.mga8
+ Revision: 1422654
- new version: 1.13.0

* Tue Feb 12 2019 daviddavid <daviddavid> 1.12.2-1.mga7
+ Revision: 1365447
- new version: 1.12.2

* Thu Jan 31 2019 daviddavid <daviddavid> 1.12.1-1.mga7
+ Revision: 1362020
- new version: 1.12.1

* Wed Jan 30 2019 daviddavid <daviddavid> 1.12.0-1.mga7
+ Revision: 1361856
- new version: 1.12.0

* Mon Dec 10 2018 daviddavid <daviddavid> 1.11.2-1.mga7
+ Revision: 1339654
- new version: 1.11.2

* Sun Nov 18 2018 daviddavid <daviddavid> 1.11.1-1.mga7
+ Revision: 1330753
- new version: 1.11.1

* Sun Sep 23 2018 umeabot <umeabot> 1.10.4-2.mga7
+ Revision: 1301141
- Mageia 7 Mass Rebuild

* Sat Aug 18 2018 daviddavid <daviddavid> 1.10.4-1.mga7
+ Revision: 1252494
- new version: 1.10.4

* Sun Mar 25 2018 daviddavid <daviddavid> 1.10.3-1.mga7
+ Revision: 1212357
- new version: 1.10.3

* Mon Jan 08 2018 daviddavid <daviddavid> 1.10.2-1.mga7
+ Revision: 1191443
- new version: 1.10.2

* Sun Jan 29 2017 daviddavid <daviddavid> 1.9.9-1.mga6
+ Revision: 1084062
- new version: 1.9.9

* Tue Dec 13 2016 daviddavid <daviddavid> 1.9.8-1.mga6
+ Revision: 1074479
- initial package spglib

